package betterquesting.api2.storage;

import javax.annotation.Nonnull;

/* loaded from: betterquesting_api2_storage.jar:betterquesting/api2/storage/DBEntry.class */
public final class DBEntry<T> implements Comparable<DBEntry<T>> {
    private final int id;

    @Nonnull
    private final T obj;

    public DBEntry(int id, T obj) {
        if (id < 0) {
            throw new IllegalArgumentException("Entry ID cannot be negative");
        }
        if (obj == null) {
            throw new NullPointerException("Entry value cannot be null");
        }
        this.id = id;
        this.obj = obj;
    }

    public final int getID() {
        return this.id;
    }

    @Nonnull
    public final T getValue() {
        return this.obj;
    }

    @Override // java.lang.Comparable
    public int compareTo(DBEntry<T> o) {
        return Integer.compare(this.id, o.id);
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof DBEntry)) {
            return false;
        }
        DBEntry entry = (DBEntry) obj;
        return getID() == entry.getID() && getValue().equals(entry.getValue());
    }
}
